@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,7 +39,9 @@ import logging.handlers
 from xl.nls import gettext as _
 from xl import common, xdg, event
 
-from xl.version import __version__
+# placeholder, - xl.version can be slow to import, which would slow down
+# cli args. Thus we import __version__ later.
+__version__ = None
 
 # initiate the logger. logger params are set later
 logger = logging.getLogger(__name__)
@@ -54,20 +56,28 @@ class Exaile(object):
         self.quitting = False
         self.loading = True
         (self.options, self.args) = self.get_options().parse_args()
+
         if self.options.ShowVersion:
             self.version()
+            return
 
         if self.options.UseDataDir:
             xdg.data_dirs.insert(1, self.options.UseDataDir)
 
-        if self.options.DebugEvent:
-            event.EVENT_MANAGER.use_logger = True
+        xdg._make_missing_dirs()
+
+        self.setup_logging()
+        global logger
+        logger = logging.getLogger(__name__)
 
         if self.options.EventFilter:
             event.EVENT_MANAGER.logger_filter = self.options.EventFilter
+            self.options.DebugEvent = True
+
+        if self.options.DebugEvent:
+            event.EVENT_MANAGER.use_logger = True
+            self.options.Debug = True
 
-        # set up logging
-        self.setup_logging()
 
         # initial mainloop setup. The actual loop is started later,
         # if necessary
@@ -76,13 +86,26 @@ class Exaile(object):
         #initialize DbusManager
         if self.options.StartGui and self.options.Dbus:
             from xl import xldbus
-            if xldbus.check_exit(self.options, self.args):
+            exit = xldbus.check_exit(self.options, self.args)
+            if exit == "exit":
                 sys.exit(0)
+            elif exit == "command":
+                if not self.options.StartAnyway:
+                    sys.exit(0)
             self.dbus = xldbus.DbusManager(self)
 
+        # import version, see note above
+        global __version__
+        from xl.version import __version__
+
         #load the rest.
         self.__init()
 
+        #handle delayed commands
+        if self.options.StartGui and self.options.Dbus and \
+                self.options.StartAnyway and exit == "command":
+            xldbus.run_commands(self.options, self.dbus)
+
         #connect dbus signals
         if self.options.Dbus:
             self.dbus._connect_signals()
@@ -128,6 +151,10 @@ class Exaile(object):
                 common.log_exception(log=logger,
                         message=_("Failed to migrate from 0.2.14"))
 
+        # Migrate old rating options
+        from xl.migrations.settings import rating
+        rating.migrate()
+
         # Initialize plugin manager
         if not self.options.SafeMode:
             from xl import plugins
@@ -143,17 +170,15 @@ class Exaile(object):
         from xl import collection
         try:
             self.collection = collection.Collection("Collection",
-                    location=os.path.join(xdg.get_data_dirs()[0], 'music.db'))
+                    location=os.path.join(xdg.get_data_dir(), 'music.db'))
         except common.VersionError:
             common.log_exception(log=logger)
             exit(1)
 
         # Set up the player and playback queue
         from xl import player
-        from xl.player import queue
-        self.player = player.get_player()()
-        self.queue = queue.PlayQueue(self.player,
-                location=os.path.join(xdg.get_data_dirs()[0], 'queue.state'))
+        self.player = player.PLAYER
+        self.queue = player.QUEUE
         event.log_event("player_loaded", self, None)
 
         # Initalize playlist manager
@@ -183,11 +208,6 @@ class Exaile(object):
         else:
             self.hal = None
 
-        # Cover manager
-        from xl import cover
-        self.covers = cover.CoverManager(
-                location=os.path.join(xdg.get_data_dirs()[0], "covers"))
-
         # Radio Manager
         from xl import radio
         self.stations = playlist.PlaylistManager('radio_stations')
@@ -208,9 +228,9 @@ class Exaile(object):
                 self.gui.main.window.iconify()
             self.gui.main.window.show_all()
 
-            import gobject
+            import glib
             if self.splash is not None:
-                gobject.idle_add(self.splash.destroy)
+                glib.idle_add(self.splash.destroy)
             event.log_event("gui_loaded", self, None)
 
 
@@ -229,7 +249,7 @@ class Exaile(object):
 
         if restore:
             self.queue._restore_player_state(
-                    os.path.join(xdg.get_data_dirs()[0], 'player.state'))
+                    os.path.join(xdg.get_data_dir(), 'player.state'))
 
         if firstrun:
             settings.set_option("general/first_run", False)
@@ -253,7 +273,8 @@ class Exaile(object):
         loglevel = logging.INFO
         if self.options.Debug:
             loglevel = logging.DEBUG
-            console_format += " (%(name)s)" # add module name in debug mode
+            console_format = "%(asctime)s,%(msecs)3d:" + console_format
+            console_format += " (%(name)s)" # add module name
         elif self.options.Quiet:
             loglevel = logging.WARNING
         # Logfile level should always be INFO or higher
@@ -262,8 +283,11 @@ class Exaile(object):
         else:
             logfilelevel = loglevel
 
+        datefmt = "%H:%M:%S"
+
         # Logging to terminal
-        logging.basicConfig(level=loglevel, format=console_format)
+        logging.basicConfig(level=loglevel, format=console_format,
+                datefmt=datefmt)
 
         # Create log directory
         logdir = os.path.join(xdg.get_data_dir(), 'logs')
@@ -290,7 +314,7 @@ class Exaile(object):
         logfile.setLevel(logfilelevel)
         formatter = logging.Formatter(
                 '%(asctime)s %(levelname)-8s: %(message)s (%(name)s)',
-                datefmt="%m-%d %H:%M")
+                datefmt=datefmt)
         logfile.setFormatter(formatter)
         logging.getLogger("").addHandler(logfile)
 
@@ -298,11 +322,21 @@ class Exaile(object):
         """
             Get the options for exaile
         """
-        from optparse import OptionParser, OptionGroup
-        usage = "Usage: %prog [option...|uri]"
-        p = OptionParser(usage=usage)
+        from optparse import OptionParser, OptionGroup, IndentedHelpFormatter
 
-        group = OptionGroup(p, _('Playback options'))
+        class OverrideHelpFormatter(IndentedHelpFormatter):
+            """
+                Merely for translation purposes
+            """
+            def format_usage(self, usage):
+                return '%s\n' % usage
+
+        usage = _("Usage: exaile [OPTION]... [URI]")
+        optionlabel = _('Options') # Merely for translation purposes
+        p = OptionParser(usage=usage, add_help_option=False,
+            formatter=OverrideHelpFormatter())
+
+        group = OptionGroup(p, _('Playback Options'))
         group.add_option("-n", "--next", dest="Next", action="store_true",
                 default=False, help=_("Play the next track"))
         group.add_option("-p", "--prev", dest="Prev", action="store_true",
@@ -313,18 +347,25 @@ class Exaile(object):
                 default=False, help=_("Play"))
         group.add_option("-t", "--play-pause", dest="PlayPause",
                 action="store_true", default=False,
-                help=_("Toggle Play or Pause"))
+                help=_("Pause or resume playback"))
         group.add_option("--stop-after-current", dest="StopAfterCurrent",
                 action="store_true", default=False,
                 help=_("Stop playback after current track"))
         p.add_option_group(group)
 
-        group = OptionGroup(p, _('Track options'))
+        group = OptionGroup(p, _('Collection Options'))
+        group.add_option("--add", dest="Add", action="store",
+                # TRANSLATORS: Meta variable for --add
+                metavar=_("LOCATION"), help=_("Add tracks from LOCATION "
+                                              "to the collection"))
+        p.add_option_group(group)
+
+        group = OptionGroup(p, _('Track Options'))
         group.add_option("-q", "--query", dest="Query", action="store_true",
                 default=False, help=_("Query player"))
         group.add_option("--gui-query", dest="GuiQuery",
                 action="store_true", default=False,
-                help=_("Show a popup of the currently playing track"))
+                help=_("Show a popup with data of the current track"))
         group.add_option("--get-title", dest="GetTitle", action="store_true",
                 default=False, help=_("Print the title of current track"))
         group.add_option("--get-album", dest="GetAlbum", action="store_true",
@@ -334,33 +375,43 @@ class Exaile(object):
         group.add_option("--get-length", dest="GetLength", action="store_true",
                 default=False, help=_("Print the length of current track"))
         group.add_option('--set-rating', dest="SetRating",
-                action='store', type='int', metavar='RATING',
-                help=_('Set rating for current song'))
+                # TRANSLATORS: Variable for command line options with arguments
+                action='store', type='int', metavar=_('N'),
+                help=_('Set rating for current track to N%'))
         group.add_option('--get-rating', dest='GetRating', action='store_true',
-                default=False, help=_('Get rating for current song'))
+                default=False, help=_('Get rating for current track'))
         group.add_option("--current-position", dest="CurrentPosition",
                 action="store_true", default=False,
-                help=_("Print the position inside the current track as time"))
+                help=_("Print the current playback position as time"))
         group.add_option("--current-progress", dest="CurrentProgress",
                 action="store_true", default=False, help=_("Print the "
-                "progress inside the current track as percentage"))
+                "current playback progress as percentage"))
         p.add_option_group(group)
 
-        group = OptionGroup(p, _('Volume options'))
+        group = OptionGroup(p, _('Volume Options'))
         group.add_option("-i", "--increase-vol", dest="IncreaseVolume",
-                action="store", type="int", metavar="VOL",
-                help=_("Increases the volume by VOL%"))
+                # TRANSLATORS: Variable for command line options with arguments
+                action="store", type="int", metavar=_("N"),
+                help=_("Increases the volume by N%"))
         group.add_option("-l", "--decrease-vol", dest="DecreaseVolume",
-                action="store", type="int", metavar="VOL",
-                help=_("Decreases the volume by VOL%"))
+                # TRANSLATORS: Variable for command line options with arguments
+                action="store", type="int", metavar=_("N"),
+                # TRANSLATORS: Meta variable for --increase-vol and--decrease-vol
+                help=_("Decreases the volume by N%"))
+        group.add_option("-m", "--toggle-mute", dest="ToggleMute",
+                action="store_true", default=False,
+                help=_("Mutes or unmutes the volume"))
         group.add_option("--get-volume", dest="GetVolume", action="store_true",
                 default=False, help=_("Print the current volume percentage"))
         p.add_option_group(group)
 
-        group = OptionGroup(p, _('Other options'))
+        group = OptionGroup(p, _('Other Options'))
         group.add_option("--new", dest="NewInstance", action="store_true",
                 default=False, help=_("Start new instance"))
-        group.add_option("--version", dest="ShowVersion", action="store_true")
+        group.add_option("-h", "--help", action="help",
+                help=_("Show this help message and exit"))
+        group.add_option("--version", dest="ShowVersion", action="store_true",
+                help=_("Show program's version number and exit."))
         group.add_option("--start-minimized", dest="StartMinimized",
                 action="store_true", default=False,
                 help=_("Start minimized (to tray, if possible)"))
@@ -372,24 +423,26 @@ class Exaile(object):
                 "useful when you're running into problems"))
         group.add_option("--force-import", dest="ForceImport",
                 action="store_true", default=False, help=_("Force import of"
-                " old data from 0.2.x. Overwrites current data."))
+                " old data from version 0.2.x (Overwrites current data)"))
         group.add_option("--no-import", dest="NoImport",
                 action="store_true", default=False, help=_("Do not import "
-                "old data from 0.2.x."))
+                "old data from version 0.2.x"))
+        group.add_option("--start-anyway", dest="StartAnyway",
+                action="store_true", default=False, help=_("Make control "
+                "options like --play start Exaile if it is not running"))
         p.add_option_group(group)
 
-        # development and debug options
-        group = OptionGroup(p, _('Development/Debug options'))
+        group = OptionGroup(p, _('Development/Debug Options'))
         group.add_option("--datadir", dest="UseDataDir",
-                help=_("Set data directory"))
+                metavar=_('DIRECTORY'), help=_("Set data directory"))
         group.add_option("--debug", dest="Debug", action="store_true",
                 default=False, help=_("Show debugging output"))
         group.add_option("--eventdebug", dest="DebugEvent",
                 action="store_true", default=False, help=_("Enable debugging"
                 " of xl.event. Generates LOTS of output"))
         group.add_option("--eventfilter", dest="EventFilter",
-                action='store', type='string', help=_("Filter event debug "
-                "output"))
+                action='store', type='string', metavar=_('TYPE'),
+                help=_("Limits event debug to output of TYPE"))
         group.add_option("--quiet", dest="Quiet", action="store_true",
                 default=False, help=_("Reduce level of output"))
         group.add_option('--startgui', dest='StartGui', action='store_true',
@@ -403,6 +456,7 @@ class Exaile(object):
         return p
 
     def version(self):
+        from xl.version import __version__
         print r"""   ____          _ __    __
   / __/_ _____ _(_) /__ / /
  / _/ \ \ / _ `/ / / -_)_/
@@ -436,7 +490,7 @@ class Exaile(object):
             self.smart_playlists.save_playlist(pl, overwrite=True)
 
     def mainloop_init(self):
-        import gobject
+        import glib, gobject
         gobject.threads_init()
         if self.options.Dbus:
             import dbus, dbus.mainloop.glib
@@ -446,8 +500,9 @@ class Exaile(object):
         if self.options.StartGui:
             import gtk
             gtk.gdk.threads_init()
+            gtk.gdk.threads_enter()
         else:
-            loop = gobject.MainLoop()
+            loop = glib.MainLoop()
             context = loop.get_context()
             self.__mainloop(context)
 
@@ -458,6 +513,8 @@ class Exaile(object):
                 context.iteration(True)
             except:
                 pass
+            finally:
+                gtk.gdk.threads_leave()
 
     def get_version(self):
         """
@@ -465,11 +522,13 @@ class Exaile(object):
         """
         return __version__
 
-    def quit(self):
+    def quit(self, restart=False):
         """
-            exits Exaile normally.
+            Exits Exaile normally. Takes care of saving
+            preferences, databases, etc.
 
-            takes care of saving prefs, databases, etc.
+            :param restart: Whether to directly restart
+            :type restart: bool
         """
         if self.quitting:
             return
@@ -484,13 +543,7 @@ class Exaile(object):
                 except:
                     pass
 
-        # stop the various idle based threads so they don't freak out
-        # when the program exits.  Silly Python.
-        event.IDLE_MANAGER.stop()
-        for timer in event._TIMERS:
-            timer.cancel()
-
-        # this event should be used by plugins and modules that dont need
+        # this event should be used by modules that dont need
         # to be saved in any particular order. modules that might be
         # touched by events triggered here should be added statically
         # below.
@@ -502,7 +555,8 @@ class Exaile(object):
         if self.gui:
             self.gui.quit()
 
-        self.covers.save()
+        from xl import covers
+        covers.MANAGER.save()
 
         self.collection.save_to_location()
 
@@ -512,14 +566,19 @@ class Exaile(object):
 
         # save player, queue
         self.queue._save_player_state(
-                os.path.join(xdg.get_data_dirs()[0], 'player.state') )
+                os.path.join(xdg.get_data_dir(), 'player.state') )
         self.queue.save_to_location(
-                os.path.join(xdg.get_data_dirs()[0], 'queue.state') )
+                os.path.join(xdg.get_data_dir(), 'queue.state') )
         self.player.stop()
 
         from xl import settings
 
-        settings._SETTINGSMANAGER.save()
+        settings.MANAGER.save()
+
+        if restart:
+            logger.info("Restarting...")
+            python = sys.executable
+            os.execl(python, python, *sys.argv)
 
         logger.info("Bye!")
         logging.shutdown()
