@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,10 @@ import logging
 logger = logging.getLogger(__name__)
 
 class ProviderManager(object):
+    """
+        The overall manager for services
+        and providers for them
+    """
     def __init__(self):
         self.services = {}
 
@@ -36,10 +40,10 @@ class ProviderManager(object):
         """
             Registers a provider.
 
-            @type servicename: string
-            @param servicename: the name of the service [string]
-            @type provider: object
-            @param provider: the object that is the provider [object]
+            :param servicename: the name of the service [string]
+            :type servicename: string
+            :param provider: the object that is the provider [object]
+            :type provider: object
         """
         if servicename not in self.services:
             self.services[servicename] = []
@@ -56,10 +60,10 @@ class ProviderManager(object):
         """
             Unregisters a provider.
 
-            @type servicename: string
-            @param servicename: the name of the service
-            @type provider: object
-            @param provider: the provider to be removed
+            :param servicename: the name of the service
+            :type servicename: string
+            :param provider: the provider to be removed
+            :type provider: object
         """
         if servicename not in self.services:
             return
@@ -81,48 +85,85 @@ class ProviderManager(object):
         """
             Returns a list of providers for the specified servicename.
 
-            @type servicename: strring
-            @param servicename: the service name to get providers for
-            @rtype: list of objects
-            @return: list of providers
+            :param servicename: the service name to get providers for
+            :type servicename: string
+            :returns: list of providers
+            :rtype: list of objects
         """
         try:
             return self.services[servicename][:]
         except KeyError:
             return []
 
+    def get_provider(self, servicename, providername):
+        """
+            Returns a single identified provider
+
+            :param servicename: The service name to get the provider for
+            :type servicename: string
+            :param providername: The provider name to identify the provider
+            :type providername: string
+            :returns: A provider or None
+            :rtype: object
+        """
+        try:
+            providers = self.services[servicename]
+        except KeyError:
+            return None
+        else:
+            for provider in providers:
+                if provider.name == providername:
+                    return provider
+
+        return None
+
 MANAGER = ProviderManager()
 register = MANAGER.register_provider
 unregister = MANAGER.unregister_provider
 get = MANAGER.get_providers
 
 class ProviderHandler(object):
+    """
+        Base framework to handle providers
+        for one specific service including
+        notification about (un)registration
+    """
     def __init__(self, servicename):
         self.servicename = servicename
-        event.add_callback(self._new_cb, "%s_provider_added" % servicename)
-        event.add_callback(self._del_cb, "%s_provider_removed" % servicename)
+        event.add_callback(self._add_callback,
+            "%s_provider_added" % servicename)
+        event.add_callback(self._remove_callback,
+            "%s_provider_removed" % servicename)
 
-    def _new_cb(self, name, obj, provider):
-        self.on_new_provider(provider)
+    def _add_callback(self, name, obj, provider):
+        """
+            Mediator to call actual callback
+            for added providers
+        """
+        self.on_provider_added(provider)
 
-    def on_new_provider(self, provider):
+    def on_provider_added(self, provider):
         """
             Called when a new provider is added.
 
-            @type provider: object
-            @param provider: the new provider
+            :param provider: the new provider
+            :type provider: object
         """
         pass # for overriding
 
-    def _del_cb(self, name, obj, provider):
-        self.on_del_provider(provider)
-
-    def on_del_provider(self, provider):
+    def _remove_callback(self, name, obj, provider):
         """
-            Called when a provider is deleted.
+            Mediator to call actual callback
+            for removed providers
+        """
+        self.on_provider_removed(provider)
 
-            @type provider: object
-            @param provider: the removed provider
+    def on_provider_removed(self, provider):
+        """
+            Called when a provider is removed.
+
+            :param provider: the removed provider
+            :type provider: object
         """
         pass # for overriding
 
@@ -130,11 +171,21 @@ class ProviderHandler(object):
         """
             Returns a list of providers for this service.
 
-            @rtype: list of objects
-            @return: list of providers
+            :returns: list of providers
+            :rtype: list of objects
         """
         return MANAGER.get_providers(self.servicename)
 
+    def get_provider(self, providername):
+        """
+            Returns a provider for this service.
+
+            :param providername: The provider name to identify the provider
+            :type providername: string
+            :returns: A provider or None
+            :rtype: object
+        """
+        return MANAGER.get_provider(self.servicename, providername)
 
 # vim: et sts=4 sw=4
 
