@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,9 +27,9 @@
 import gobject
 import gtk
 
+from xl import metadata, trax
 from xl.nls import gettext as _
 from xlgui import panel, guiutil, menu
-from xl import metadata
 
 class FlatPlaylistPanel(panel.Panel):
     """
@@ -37,6 +37,7 @@ class FlatPlaylistPanel(panel.Panel):
     """
     __gsignals__ = {
         'append-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
+        'replace-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
         'queue-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
     }
 
@@ -60,23 +61,25 @@ class FlatPlaylistPanel(panel.Panel):
             'on_import_button_clicked': self._on_import_button_clicked,
         })
         self.menu.connect('append-items', lambda *e:
-            self.emit('append-items', self.get_selected_tracks()))
+            self.emit('append-items', self.tree.get_selected_tracks()))
+        self.menu.connect('replace-items', lambda *e:
+            self.emit('replace-items', self.tree.get_selected_tracks()))
         self.menu.connect('queue-items', lambda *e:
-            self.emit('queue-items', self.get_selected_tracks()))
+            self.emit('queue-items', self.tree.get_selected_tracks()))
         self.tree.connect('row-activated', lambda *e:
-            self.emit('append-items', self.get_selected_tracks()))
+            self.emit('append-items', self.tree.get_selected_tracks()))
 
     def _on_add_button_clicked(self, *e):
         self.emit('append-items', self.tracks)
 
     def _on_import_button_clicked(self, *e):
-        tracks = self.get_selected_tracks()
+        tracks = self.tree.get_selected_tracks()
         if len(tracks) == 0: # nothing selected, do everything
             tracks = self.tracks
         self.parent.do_import(tracks)
 
     def _setup_tree(self):
-        self.tree = guiutil.DragTreeView(self, False, True)
+        self.tree = FlatPlaylistDragTreeView(self, False, True)
         selection = self.tree.get_selection()
         selection.set_mode(gtk.SELECTION_MULTIPLE)
 
@@ -118,18 +121,6 @@ class FlatPlaylistPanel(panel.Panel):
         for i, track in enumerate(tracks):
             self.model.append([i + 1, track.get_tag_display("title"), track])
 
-    def get_selected_tracks(self):
-        selection = self.tree.get_selection()
-        (model, paths) = selection.get_selected_rows()
-
-        tracks = []
-        for path in paths:
-            iter = self.model.get_iter(path)
-            track = self.model.get_value(iter, 2)
-            tracks.append(track)
-
-        return tracks
-
     def button_press(self, button, event):
         """
             Called when the user clicks on the playlist
@@ -143,7 +134,7 @@ class FlatPlaylistPanel(panel.Panel):
             if not path:
                 return False
 
-            if len(self.get_selected_tracks()) >= 2:
+            if len(self.tree.get_selected_tracks()) >= 2:
                 (mods,paths) = selection.get_selected_rows()
                 if (path[0] in paths):
                     if event.state & (gtk.gdk.SHIFT_MASK|gtk.gdk.CONTROL_MASK):
@@ -169,10 +160,28 @@ class FlatPlaylistPanel(panel.Panel):
         """
             Called when a drag source wants data for this drag operation
         """
-        tracks = self.get_selected_tracks()
+        tracks = self.tree.get_selected_tracks()
         if not tracks: return
         for track in tracks:
             guiutil.DragTreeView.dragged_data[track.get_loc_for_io()] = track
-        urls = guiutil.get_urls_for(tracks)
-        selection.set_uris(urls)
+        uris = trax.util.get_uris_from_tracks(tracks)
+        selection.set_uris(uris)
+
+class FlatPlaylistDragTreeView(guiutil.DragTreeView):
+    """
+        Custom DragTreeView to retrieve data from playlists
+    """
+    def get_selected_tracks(self):
+        """
+            Returns the currently selected tracks
+        """
+        (model, paths) = self.get_selection().get_selected_rows()
+        tracks = []
+
+        for path in paths:
+            iter = model.get_iter(path)
+            track = model.get_value(iter, 2)
+            tracks.append(track)
+
+        return tracks
 
