@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,14 +39,14 @@ from xl.nls import gettext as _
 
 IGNORE = (None, None)
 
-dialog_tags = { 'originalalbum': (_('Original Album'), 'text'),
+dialog_tags = { 'originalalbum': (_('Original album'), 'text'),
                 'lyricist': (_('Lyricist'), 'text'),
                 'part': IGNORE, #
                 'website': (_('Website'), 'text'),
                 'cover': IGNORE, #
-                'originalartist': (_('Original Artist'), 'text'),
+                'originalartist': (_('Original artist'), 'text'),
                 'author': (_('Author'), 'text'),
-                'originaldate': (_('Original Date'), 'int', 1000, 2100),
+                'originaldate': (_('Original date'), 'int', 1000, 2100),
                 'date': (_('Date'), 'text'),
                 'arranger': (_('Arranger'), 'text'),
                 'conductor': (_('Conductor'), 'text'),
@@ -61,24 +61,24 @@ dialog_tags = { 'originalalbum': (_('Original Album'), 'text'),
                 'isrc': (_('ISRC'), 'text'),
                 'genre': (_('Genre'), 'text'),
                 'composer': (_('Composer'), 'text'),
-                'encodedby': (_('Encoded By'), 'text'),
+                'encodedby': (_('Encoded by'), 'text'),
                 'organization': (_('Organization'), 'text'),
                 'discnumber': (_('Disc'), 'int', 0, 50),
                 'bpm': (_('BPM'), 'int', 0, 300),
                 '__bitrate': (_('Bitrate'), 'prop:bitrate'),
-                '__date_added': (_('Date Added'), 'prop:datetime'),
+                '__date_added': (_('Date added'), 'prop:datetime'),
                 '__length': (_('Length'), 'prop:time'),
                 '__loc': (_('Location'), 'prop:location'),
                 '__basedir': IGNORE,
                 '__modified': (_('Modified'), 'prop:datetime'),
                 '__playtime': IGNORE,
-                '__playcount': (_('Times Played'), 'text'),
-                '__last_played': (_('Last Played'), 'prop:datetime'),
+                '__playcount': (_('Times played'), 'text'),
+                '__last_played': (_('Last played'), 'prop:datetime'),
                 }
 
 class TrackPropertiesDialog(gobject.GObject):
 
-    def __init__(self, parent, tracks):
+    def __init__(self, parent, tracks, selected=None):
         gobject.GObject.__init__(self)
 
         self.builder = gtk.Builder()
@@ -93,9 +93,6 @@ class TrackPropertiesDialog(gobject.GObject):
         self.apply_button = self.builder.get_object('apply_button')
         self.prev_button = self.builder.get_object('prev_track_button')
         self.next_button = self.builder.get_object('next_track_button')
-        self.prev_button.set_sensitive(False)
-        if len(tracks) == 1:
-            self.next_button.set_sensitive(False)
 
         self.tags_table = self.builder.get_object('tags_table')
         self.properties_table = self.builder.get_object('properties_table')
@@ -124,7 +121,11 @@ class TrackPropertiesDialog(gobject.GObject):
         self.tracks = self._tags_copy(tracks)
         self.tracks_original = self._tags_copy(tracks)
 
-        self.current = 0
+        if selected:
+            self.current = selected
+        else:
+            self.current = 0
+
         self._build_from_track(self.current)
 
         self.dialog.resize(600, 350)
@@ -260,24 +261,27 @@ class TrackPropertiesDialog(gobject.GObject):
             if tag not in self.def_tags:
 
                 try:
-                    type = dialog_tags[tag][1]
+                    fieldtype = dialog_tags[tag][1]
                 except KeyError:
-                    type = 'text'
+                    fieldtype = 'text'
 
-                if type is not None:
+                if fieldtype is not None:
                     for i, entry in enumerate(t[tag]):
                         f = None
                         if not tag.startswith('__'):
-                            if type == 'int':
+                            if fieldtype == 'int':
                                 f = TagNumField(dialog_tags[tag][2],
                                         dialog_tags[tag][3], all_button=ab)
                             else:
-                                f = TagField(all_button=ab)
+                                if tag == 'lyrics':
+                                    f = TagTextField(all_button=ab)
+                                else:
+                                    f = TagField(all_button=ab)
 
                             self.rows.append(TagRow(self, self.tags_table, f, tag, entry, i))
 
                         else:
-                            f = PropertyField(type)
+                            f = PropertyField(fieldtype)
 
                             self.rows.append(TagRow(self, self.properties_table, f, tag, entry, i))
 
@@ -364,7 +368,7 @@ class TrackPropertiesDialog(gobject.GObject):
 
     def _title_case(self, w):
         for row in self.rows:
-            if isinstance(row.field, TagField):
+            if isinstance(row.field, TagField) or isinstance(row.field, TagTextField):
                 val = row.field.get_value()
                 val = string.capwords(val, ' ')
                 row.field.set_value(val)
@@ -523,12 +527,14 @@ class TagRow(object):
             self.label = gtk.Label()
 
         self.clear_button = gtk.Button()
-        im = gtk.Image()
-        im.set_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_BUTTON)
-        self.clear_button.set_image(im)
+        self.clear_button.set_image(
+            gtk.image_new_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_BUTTON)
+        )
         self.clear_button.connect("clicked", self.clear)
+
         if not isinstance(field, PropertyField):
             self.field.pack_start(self.clear_button, expand=False, fill=False)
+
         self.field.show_all()
 
         #Remove mode settings
@@ -606,6 +612,61 @@ class TagField(gtk.HBox):
     def register_all_func(self, f):
         self.all_func = f
 
+class TagTextField(gtk.HBox):
+    def __init__(self, all_button=True):
+        gtk.HBox.__init__(self, homogeneous=False, spacing=5)
+
+        self.buffer = gtk.TextBuffer()
+        self.field = gtk.TextView(self.buffer)
+        self.field.set_size_request(200, 150) # XXX
+        scrollwindow = gtk.ScrolledWindow()
+        scrollwindow.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+        scrollwindow.set_shadow_type(gtk.SHADOW_IN)
+        scrollwindow.add(self.field)
+        self.all_func = None
+        self.parent_row = None
+
+        self.pack_start(scrollwindow)
+
+        self.all_button = None
+        if all_button:
+            self.all_button = AllButton(self)
+            self.pack_start(self.all_button, expand=False, fill=False)
+
+    def register_parent_row(self, parent_row):
+        self.parent_row = parent_row
+
+    def set_value(self, val, all_vals=None, doupdate=True):
+        if doupdate:
+            self.buffer.set_text(val)
+
+        if all_vals != None and self.all_button != None:
+            #Set the value of the all button
+            flag = True
+            for v in all_vals:
+                if val != v:
+                    flag = False
+
+            if flag:
+                self.all_button.set_active(True)
+            else:
+                self.all_button.set_active(False)
+
+    def get_value(self):
+        return self.buffer.get_text(
+            self.buffer.get_start_iter(),
+            self.buffer.get_end_iter(),
+            True
+        )
+
+    def register_update_func(self, f):
+        tag = self.parent_row.tag
+        multi_id = self.parent_row.multi_id
+        self.buffer.connect("changed", f, tag, multi_id, self.get_value)
+
+    def register_all_func(self, f):
+        self.all_func = f
+
 class TagNumField(gtk.HBox):
     def __init__(self, min=0, max=10000, step=1, page=10, all_button=True):
         gtk.HBox.__init__(self, homogeneous=False, spacing=5)
@@ -754,9 +815,9 @@ class PropertyField(gtk.HBox):
 
         if self.property_type == 'prop:location':
             self.folder_button = gtk.Button()
-            im = gtk.Image()
-            im.set_from_stock(gtk.STOCK_DIRECTORY, gtk.ICON_SIZE_BUTTON)
-            self.folder_button.set_image(im)
+            self.folder_button.set_tooltip_text(_('Open Directory'))
+            self.folder_button.set_image(gtk.image_new_from_stock(
+                gtk.STOCK_OPEN, gtk.ICON_SIZE_BUTTON))
             self.pack_start(self.folder_button, expand=False, fill=False)
             self.folder_button.connect("clicked", self.folder_button_clicked)
 
@@ -768,7 +829,7 @@ class PropertyField(gtk.HBox):
             output = str( val / 1000.0 ) + ' Kbps'
         elif self.property_type == 'prop:datetime':
             d = datetime.datetime.fromtimestamp(val)
-            output = d.strftime("%Y/%m/%d %H:%M:%S")
+            output = d.strftime("%x %X")
         elif self.property_type == 'prop:time':
             output = "%(m)d:%(s)02d" % {'m': val // 60, 's': val % 60}
         elif self.property_type == 'prop:location':
