@@ -18,7 +18,7 @@ import _scrobbler as scrobbler
 import asprefs
 from xl import common, event, xdg, metadata, settings
 from xl.nls import gettext as _
-import gobject, logging, time, pickle, os, gtk
+import glib, logging, time, pickle, os, gtk
 
 logger = logging.getLogger(__name__)
 
@@ -38,7 +38,7 @@ def enable(exaile):
         __enb(None, exaile, None)
 
 def __enb(eventname, exaile, nothing):
-    gobject.idle_add(_enable, exaile)
+    glib.idle_add(_enable, exaile)
 
 def _enable(exaile):
     SCROBBLER.exaile_menu = exaile.gui.builder.get_object('tools_menu')
@@ -54,7 +54,7 @@ def disable(exaile):
         SCROBBLER.stop()
         SCROBBLER = None
 
-def get_prefs_pane():
+def get_preferences_pane():
     return asprefs
 
 class ExaileScrobbler(object):
@@ -74,7 +74,7 @@ class ExaileScrobbler(object):
         self.get_options('','','plugin/ascrobbler/cache_size')
         self.get_options('','','plugin/ascrobbler/user')
         self.load_cache()
-        event.add_callback(self.get_options, 'option_set')
+        event.add_callback(self.get_options, 'plugin_ascrobbler_option_set')
         event.add_callback(self._save_cache_cb, 'quit_application')
 
     def get_options(self, type, sm, option):
@@ -91,7 +91,7 @@ class ExaileScrobbler(object):
                 'http://post.audioscrobbler.com/')
             self.submit = settings.get_option('plugin/ascrobbler/submit', True)
 
-            if self.use_menu and self.menu_entry:
+            if self.use_menu:
                 self.menu_entry.set_active(self.submit)
 
             if (not self.connecting and not self.connected) and self.submit:
@@ -101,9 +101,9 @@ class ExaileScrobbler(object):
 
         if option == 'plugin/ascrobbler/menu_check':
             self.use_menu = settings.get_option('plugin/ascrobbler/menu_check', False)
-            if self.use_menu and not self.menu_entry:
+            if self.use_menu:
                 self.setup_menu()
-            elif self.menu_entry and not self.use_menu:
+            elif self.menu_entry:
                 self.remove_menu()
 
     def setup_menu(self):
@@ -181,13 +181,16 @@ class ExaileScrobbler(object):
             return
 
         logger.info("Attempting to submit \"Now Playing\" information to AudioScrobbler...")
-        scrobbler.now_playing(
-            track.get_tag_raw('artist', join=True),
-            track.get_tag_raw('title', join=True),
-            track.get_tag_raw('album', join=True),
-            int(track.get_tag_raw('__length')),
-            track.split_numerical(track.get_tag_raw('tracknumber'))[0] or 0
+        try:
+            scrobbler.now_playing(
+                track.get_tag_raw('artist', join=True),
+                track.get_tag_raw('title', join=True),
+                track.get_tag_raw('album', join=True),
+                int(track.get_tag_raw('__length')),
+                track.split_numerical(track.get_tag_raw('tracknumber'))[0] or 0
             )
+        except Exception, e:
+            logger.warning("Error submitting \"Now Playing\": %s" % e)
 
     def on_play(self, type, player, track):
         track.set_tag_raw('__audioscrobbler_playtime',
