@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # Bookmark plugin for Exaile media player
-# Copyright (C) 2009 Brian Parma
+# Copyright (C) 2009-2010 Brian Parma
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,20 +17,28 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
-
 from __future__ import with_statement
-from xl.nls import gettext as _
-from xl import event, xdg, trax, settings
-from xlgui import commondialogs, guiutil, cover as guicover
-import gtk
-import gobject
 import gio
+import glib
+import gtk
 import os
 import logging
-import bookmarksprefs
 logger = logging.getLogger(__name__)
 
+from xl import (
+    covers,
+    event,
+    player,
+    settings,
+    trax,
+    xdg,
+)
+from xl.nls import gettext as _
+from xlgui import guiutil, icons
+from xlgui.widgets import dialogs
+
+import bookmarksprefs
+
 
 MENU_ITEM                   = None
 
@@ -38,7 +46,7 @@ MENU_ITEM                   = None
 
 def error(text):
     logger.error("%s: %s" % ('Bookmarks', text))
-    commondialogs.error(None, exaile.gui.main, text)
+    dialogs.error(None, exaile.gui.main, text)
 
 class Bookmarks:
     def __init__(self, exaile):
@@ -66,29 +74,29 @@ class Bookmarks:
             return
 
         # check if it's already playing
-        track = exaile.player.current
+        track = player.PLAYER.current
         if track:
             if track.get_loc_for_io() == key:
-                exaile.player.unpause()
-                exaile.player.seek(pos)
+                player.PLAYER.unpause()
+                player.PLAYER.seek(pos)
                 return
         else:
             # use currently selected playlist (as opposed to current playlist)
             track = trax.Track(key)
             if track:   # make sure we got one
                 pl = exaile.gui.main.get_selected_playlist().playlist
-                exaile.queue.set_current_playlist(pl)
-                exaile.queue.current_playlist.add(track)
+                player.QUEUE.set_current_playlist(pl)
+                player.QUEUE.current_playlist.add(track)
 
         # try and play/seek
         if track:
 #            print 'bk: seeking to ', pos,type(pos)
-            idx = exaile.queue.current_playlist.index(track)
-            exaile.queue.current_playlist.set_current_pos(idx)
-            #exaile.player.stop()   # prevents crossfading
-            exaile.queue.play(track)
-            exaile.player.unpause()
-            exaile.player.seek(pos)
+            idx = player.QUEUE.current_playlist.index(track)
+            player.QUEUE.current_playlist.set_current_pos(idx)
+            #player.PLAYER.stop()   # prevents crossfading
+            player.QUEUE.play(track)
+            player.PLAYER.unpause()
+            player.PLAYER.seek(pos)
 
 
     def add_bookmark(self, widget, menus):
@@ -96,12 +104,12 @@ class Bookmarks:
             Create bookmark for current track/position.
         """
         # get currently playing track
-        track = self.exaile.player.current
+        track = player.PLAYER.current
         if track is None:
             error('Need a playing track to Bookmark.')
             return
 
-        pos = self.exaile.player.get_time()
+        pos = player.PLAYER.get_time()
         key = track.get_loc_for_io()
         self.bookmarks.append((key,pos))
         self.display_bookmark(key, pos, menus)
@@ -118,11 +126,11 @@ class Bookmarks:
             item = trax.Track(key)
             title = item.get_tag_display('title')
             if self.use_covers:
-                image = self.exaile.covers.get_cover(item, set_only=True)
+                image = covers.MANAGER.get_cover(item, set_only=True)
                 if image:
                     try:
-                        pix = guicover.pixbuf_from_data(image, scale=(16,16))
-                    except gobject.GError:
+                        pix = icons.MANAGER.pixbuf_from_data(image, size=(16,16))
+                    except glib.GError:
                         logger.warn('Could not load cover')
                         pix = None
                         # no cover
@@ -229,7 +237,7 @@ class Bookmarks:
 
 
 def __enb(eventname, exaile, nothing):
-    gobject.idle_add(_enable, exaile)
+    glib.idle_add(_enable, exaile)
 
 def enable(exaile):
     """
@@ -259,16 +267,16 @@ def _enable(exaile):
 
     menus = [guiutil.Menu(), guiutil.Menu()]
 
-    menu_item = gtk.ImageMenuItem(_('Bookmark this track'))
+    menu_item = gtk.ImageMenuItem(_('Bookmark This Track'))
     menu_item.connect('activate', bm.add_bookmark, menus)
     menu_item.set_image(gtk.image_new_from_icon_name('bookmark-new', gtk.ICON_SIZE_MENU))
     menus[0].append_item(menu_item)
 
-    menu_item = gtk.MenuItem(_('Delete bookmark'))
+    menu_item = gtk.MenuItem(_('Delete Bookmark'))
     menu_item.set_submenu(menus[1])
     menus[0].append_item(menu_item)
 
-    menus[0].append(_('Clear bookmarks'), bm.clear, 'gtk-clear', menus)
+    menus[0].append(_('Clear Bookmarks'), bm.clear, gtk.STOCK_CLEAR, menus)
 
     menus[0].append_separator()
 
@@ -304,5 +312,5 @@ if __name__ == '__main__':
     print get_time()
 
 # vi: et ts=4 sts=4 sw=4
-def get_prefs_pane():
+def get_preferences_pane():
     return bookmarksprefs
