@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
+# Copyright (C) 2009-2010 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 import os
-from xlgui.prefs import widgets
+from xlgui.preferences import widgets
 from xl import xdg
 from xl.nls import gettext as _
 
@@ -24,7 +24,7 @@ basedir = os.path.dirname(os.path.realpath(__file__))
 ui = os.path.join(basedir, "bookmarks_pane.ui")
 
 
-class UseCovers(widgets.CheckPrefsItem):
+class UseCovers(widgets.CheckPreference):
     default = False
     name = 'plugin/bookmarks/use_covers'
 
