@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Aren Olson
+# Copyright (C) 2009-2010 Aren Olson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ import gst
 
 try:
     import replaygainprefs
-    def get_prefs_pane():
+    def get_preferences_pane():
         return replaygainprefs
 except: # fail gracefully if we cant set up the UI
     pass
@@ -67,14 +67,14 @@ class ReplaygainVolume(ElementBin):
         self.elements[50] = self.rgvol
         self.setup_elements()
 
-        event.add_callback(self._on_setting_change, "replaygain_option_set")
+        event.add_callback(self._on_option_set, "replaygain_option_set")
 
         # load settings
         for x in ("album-mode", "pre-amp", "fallback-gain"):
-            self._on_setting_change("replaygain_option_set", None,
+            self._on_option_set("replaygain_option_set", None,
                     "replaygain/%s"%x)
 
-    def _on_setting_change(self, name, object, data):
+    def _on_option_set(self, name, object, data):
         if data == "replaygain/album-mode":
             self.rgvol.set_property("album-mode",
                     settings.get_option("replaygain/album-mode", True))
@@ -103,11 +103,11 @@ class ReplaygainLimiter(ElementBin):
         self.elements[60] = self.audioconvert
         self.setup_elements()
 
-        event.add_callback(self._on_setting_change, "replaygain_option_set")
-        self._on_setting_change("replaygain_option_set", None,
+        event.add_callback(self._on_option_set, "replaygain_option_set")
+        self._on_option_set("replaygain_option_set", None,
                 "replaygain/clipping-protection")
 
-    def _on_setting_change(self, name, object, data):
+    def _on_option_set(self, name, object, data):
         if data == "replaygain/clipping-protection":
             self.rglimit.set_property("enabled",
                     settings.get_option("replaygain/clipping-protection",
